ShEx — linkml documentation

# ShEx

## Overview

ShEx, short for Shape Expressions Language is a modeling language for RDF files.

See also

ShEx Primer notebook

## Docs

### Command Line

#### gen-shex

Generate a ShEx Schema for a LinkML model

    gen-shex [OPTIONS] YAMLFILE

Options

-o, --output <output>

  Output file name

-f, --format <format>

  Output format (default=shex)

  Options

    shex | json | rdf

--metadata, --no-metadata

  Include metadata in output (default=–metadata)

--useuris, --metauris

  Include metadata in output (default=–useuris)

-im, --importmap <importmap>

  Import mapping file

--log_level <log_level>

  Logging level (default=WARNING)

  Options

    CRITICAL | ERROR | WARNING | INFO | DEBUG

--mergeimports, --no-mergeimports

  Merge imports into source file (default=mergeimports)

Arguments

YAMLFILE

  Required argument

### Code